from corpusparser import Parser 
import argparse
import logging
import json

logging.basicConfig(level=logging.INFO)
logger = logging.getLogger(__name__)

## Main handles command line arguments and writing to files / DB.  

if __name__ == "__main__":
	parser = argparse.ArgumentParser(description="Parsing corpora kres and ssj500k.")
	parser.add_argument('--kres-folder', required=True)
	parser.add_argument('--kres-srl-folder', required=True)
	parser.add_argument('--ssj-file', required=True)
	parser.add_argument('--output', required=False, default=None)
	parser.add_argument('--outdir', required=False, default=None)
	parser.add_argument('--dbaddr', required=False, default=None)
	args = parser.parse_args()

	# parse ssj
	logger.info("Parsing ssj500k: {}".format(args.ssj_file))
	ssj_parser = Parser(
		corpus="ssj",
		infiles=[args.ssj_file],
		output=args.output,
		outdir=args.outdir,
	)
	res = [x[1]["sid"] for x in ssj_parser.sentence_generator()]
	logger.info("Parsed {} sentences (ssj500k)".format(len(res)))

	# parse kres
	logger.info("Parsing Kres: {}".format(args.ssj_file))
	kres_parser = Parser(
		corpus="kres",
		infiles=[args.kres_folder, args.kres_srl_folder],
		output=args.output,
		outdir=args.outdir,
	)
	res = [x[1]["sid"] for x in kres_parser.sentence_generator()]
	logger.info("Parsed {} sentences (kres)".format(len(res)))


## Handling output is situational --- implement it outside of Parser.
## Parser returns tuples (orig_file, element)
# 1. parse per-file and output to file (JSON)
# 2. parse and save to DB

# TODO
def handle_output(self, sent_ent, xml_file):
    if self.output is None:
        pass
    if self.output == "file":
        outfile = Path(self.outdir) / Path(xml_file.name.split(".")[0]).with_suffix(".json")
        with outfile.open("a") as fp:
            print(sent_ent)
            json.dumps(sent_ent, fp)

